'''
Created on 16 mars 2021

@author: laborie
'''
from django.core.exceptions import ValidationError
from django.utils.translation import gettext as _, ngettext

class ContainSpecialChar:
    def __init__(self,
                 special_char_count=1,
                 special_char_list=['@', '-', '_', '*', '$', '+',
                                    '=', '#', '!', '&']):
        self.special_char_list = special_char_list
        self.special_char_count = special_char_count

    def validate(self, password, user=None):
        count = 0
        for special_char in self.special_char_list:
            if special_char in password:
                count += 1
            if count == self.special_char_count:
                return None
        raise ValidationError(
            _("This password must contain at least %(special_char_count)d characters in %(special_char_list)s."),
            code='need_special_char',
            params={'special_char_count': self.special_char_count,
                    'special_char_list': ''.join(self.special_char_list)},
        )

    def get_help_text(self):
        return ngettext(
            "Your password must contain at least %(special_char_count)d special character in %(special_char_list)s",
            "Your password must contain at least %(special_char_count)d specials characters in %(special_char_list)s",
            self.special_char_count
        ) % {'special_char_count': self.special_char_count,
             'special_char_list': ''.join(self.special_char_list)}


class ContainLetterChar:
    def __init__(self, letter_count=1):
        self.letter_count = letter_count

    def validate(self, password, user=None):
        count = 0
        for character in password:
            if character.isalpha():
                count += 1
            if count == self.letter_count:
                return None
        raise ValidationError(
            _("This password must contain at least %(letter_count)d letter."),
            code='need_more_letter',
            params={'letter_count': self.letter_count},
        )

    def get_help_text(self):
        return ngettext(
            "Your password must contain at least %(letter_count)d letter",
            "Your password must contain at least %(letter_count)d letters",
            self.letter_count
        ) % {'letter_count': self.letter_count}


class ContainDigit:
    def __init__(self, digit_count=1):
        self.digit_count = digit_count

    def validate(self, password, user=None):
        count = 0
        for character in password:
            if character.isdigit():
                count += 1
            if count == self.digit_count:
                return None
        raise ValidationError(
            _("This password must contain at least %(digit_count)d digit."),
            code='need_more_letter',
            params={'digit_count': self.digit_count},
        )

    def get_help_text(self):
        return ngettext(
            "Your password must contain at least %(digit_count)d digit",
            "Your password must contain at least %(digit_count)d digits",
            self.digit_count
        ) % {'digit_count': self.digit_count}
